@@ -622,5 +622,12 @@ $(document).ready(function() {
 			
 		}
 	}
+	
+	$('.membershipForm').submit(function() {
+		var name = $(this).find("input[name='item_name']").attr('value');
+		var price = $(this).find("input[name='amount']").attr('value');
+		console.log("Adding tracking for: " + name)
+		return Arnolfini.trackEcommerce(name, price, 'Membership');
+	});
 });
 
