@@ -98,7 +98,7 @@ class CommonBrowserView(BrowserView):
         
     def addPaypalButton(self, label, name, price):
         return """
-            <form action="https://www.paypal.com/cgi-bin/webscr" method="post" onSubmit="return Arnolfini.trackEcommerce('%(name)s', '%(price).2f')">
+            <form action="https://www.paypal.com/cgi-bin/webscr" method="post" onSubmit="return Arnolfini.trackEcommerce('%(name)s', '%(price).2f', 'Book')">
                 <input name="business" type="hidden" value="arnolfini@intk.com" />
                 <input name="amount" type="hidden" value="%(price).2f" />
                 <input name="item_name" type="hidden" value="%(name)s" />
@@ -291,10 +291,14 @@ class CommonBrowserView(BrowserView):
         if event.portal_type != 'Event' and event.portal_type != 'Media Event':
             return False
         else:
+            t = DateTime(time.time())
             if event.end() is not None:
-                return event.end() < time.time()
+                end = DateTime(event.end())
+                return end.year() < t.year() or (end.year() == t.year() and end.month() < t.month()) or(end.year() == t.year() and end.month() == t.month() and end.day() < t.day())
             else:
-                return event.start() < time.time()
+                start = DateTime(event.start())
+                return start.year() < t.year() or (start.year() == t.year() and start.month() < t.month()) or(start.year() == t.year() and start.month() == t.month() and start.day() < t.day())
+            
     
     def getCurrentTime(self):
         """
@@ -540,7 +544,7 @@ class EventListingView(FolderListing):
         today = DateTime()
         
         for res in self.cachedResults:
-            if res.start.strftime("%d/%m/%Y") == today.strftime("%d/%m/%Y") and res.end <= today:
+            if res.start.strftime("%d/%m/%Y") == today.strftime("%d/%m/%Y"):
                 res_list.append(res)
             elif res.start <= today and today <= res.end:
                 res_list.append(res)
